;; Generated package description from zones.el  -*- no-byte-compile: t -*-
(define-package "zones" "2023.6.11" "Zones of text - like multiple regions" 'nil :commit "10ebf386d48725fa3af2f8b0c60ad4ffa0ec9653" :maintainer '("Drew Adams" . "drew.adams@oracle.com") :keywords '("narrow" "restriction" "widen" "region" "zone") :url "https://elpa.gnu.org/packages/zones.html")
